import { memo, useState, useEffect } from 'react';
import { useChatBot } from '../chat-bot';
import ChatMessage from '../message/chat-message';
import ChatHeader from './chat-header';
import ChatFooter from './chat-footer';

const urlModule = window.drupalSettings?.deepseek?.url_module || '';

function ChatBox() {

  const {loading, messages, upFile, voiceChat, voiceStatus, startVoice, stopVoice, setMessages, sendMessage, newChat, removeChat, regenerateChat, copyChat, editChatStart, editChatStop, speakChat, handleScroll, setUpFile, upLoad} = useChatBot();

  const [showChat, setShowChat] = useState(false);

  useEffect(() => {
    const btn = document.getElementById('chat-bot');
    if (btn) {
      const handleClick = () => setShowChat(true);
      btn.addEventListener("click", handleClick);
      return () => {
        btn.removeEventListener("click", handleClick);
      };
    }
  }, []);

  return (
    showChat && <div className={'chat-bot chat-box'}>
      <div className={`chat-box-iframe position-fixed overflow-hidden rounded-3 bg-light shadow`}>
        <div className='d-flex flex-column w-100 h-100'>
          <ChatHeader setShowChat={setShowChat} setMessages={setMessages} newChat={newChat} removeChat={removeChat} />
          <ChatMessage loading={loading} messages={messages} regenerateChat={regenerateChat} copyChat={copyChat} editChatStart={editChatStart} editChatStop={editChatStop} speakChat={speakChat} handleScroll={handleScroll} urlModule={urlModule} />
          <ChatFooter upFile={upFile} voiceChat={voiceChat} voiceStatus={voiceStatus} startVoice={startVoice} stopVoice={stopVoice} sendMessage={sendMessage} setUpFile={setUpFile} upLoad={upLoad} />
        </div>
      </div>
    </div>
  );
}
export default memo(ChatBox);
