import { memo, useState } from 'react';
import { useChatBot } from '../chat-bot';
import ChatMessage from '../message/chat-message';
import ChatHistory from './chat-history';
import ChatTrix from '../message/chat-trix';
import ChatUpfile from '../message/chat-upfile';
import ChatFooter from './chat-footer';

const urlModule = window.drupalSettings?.deepseek?.url_module || '';

function ChatPage() {
  const { messages, loading, session, voiceChat, voiceStatus, lang, upFile, editChatStart, editChatStop, speakChat, copyChat, sendMessage, upLoad, newChat, handleScroll, regenerateChat, changeLang, setSessions, setUpFile, startVoice, stopVoice } = useChatBot();

  const [historyStatus, setHistoryStatus] = useState(false);
  const [input, setInput] = useState('');

  const handleSendMessage = () => {
    setInput('');
    sendMessage(input);
  };

  return (
    <div className='chat-bot chat-page'>
      <div className='d-flex flex-column h-100 mx-lg-5 p-3 bg-white'>
        <ChatMessage loading={loading} messages={messages} regenerateChat={regenerateChat} urlModule={urlModule} copyChat={copyChat} editChatStart={editChatStart} editChatStop={editChatStop} speakChat={speakChat} handleScroll={handleScroll} />
        {upFile.length > 0 && <ChatUpfile upFile={upFile} setUpFile={setUpFile} /> }
        <ChatTrix input={input} lang={lang} voiceChat={voiceChat} setInput={setInput} upLoad={upLoad} voiceStatus={voiceStatus} changeLang={changeLang} startVoice={startVoice} stopVoice={stopVoice} handleSendMessage={handleSendMessage} />
        <ChatFooter newChat={newChat} handleSendMessage={handleSendMessage} setHistoryStatus={setHistoryStatus} />
      </div>
      {historyStatus &&  <ChatHistory session={session} newChat={newChat} setSessions={setSessions} setHistoryStatus={setHistoryStatus} />}
    </div>
  );
}
export default memo(ChatPage);
