import { memo, useEffect, useRef } from 'react';
import { Form  } from 'react-bootstrap';
import 'trix/dist/trix.css';
import 'trix';
import ChatFile from './chat-file';
import ChatVoice from './chat-voice';

const languages = [
    { 'en-US': 'English' },
    { 'fr-FR': 'Français' },
    { 'it-IT': 'Italiano' },
    { 'es-ES': 'Español' },
    { 'ca-ES': 'Català' },
    { 'gl-ES': 'Galego' },
    { 'pt-PT': 'Português' },
    { 'pt-BR': 'Brasil' },
    { 'vi-VN': 'Tiếng Việt' },
    { 'af-ZA': 'Afrikaans' },
    { 'bs-BA': 'Bosanski' },
    { 'id-ID': 'Bahasa' },
    { 'jv-ID': 'Basa Java' },
    { 'cy-GB': 'Cymraeg' },
    { 'da-DK': 'Dansk' },
    { 'de-DE': 'Deutsch' },
    { 'et-EE': 'Eesti' },
    { 'eu-ES': 'Euskera' },
    { 'fa-IR': 'Farsi' },
    { 'fil-PHe': 'Filipino' },
    { 'ga-IE': 'Gaeilge' },
    { 'hr-HR': 'Hrvatski' },
    { 'sw-KE': 'Kiswahili' },
    { 'kk-KZ': 'Қазақ' },
    { 'lt-LT': 'Lietuvių' },
    { 'lv-LV': 'Latviešu' },
    { 'mt-MT': 'Malti' },
    { 'hu-HU': 'Magyar' },
    { 'nl-NL': 'Nederlands' },
    { 'uz-UZ': 'Oʻzbekcha' },
    { 'pl-PL': 'Polski' },
    { 'sq-AL': 'Shqip' },
    { 'sv-SE': 'Svenska' },
    { 'fi-FI': 'Suomi' },
    { 'cs-CZ': 'Čeština' },
    { 'is-IS': 'Íslenska' },
    { 'ro-RO': 'Română' },
    { 'tr-TR': 'Türkçe' },
    { 'sk-SK': 'Slovenčina' },
    { 'el-GR': 'Ελληνικά' },
    { 'az-AZ': 'Azərbaycanca' },
    { 'bg-BG': 'Български' },
    { 'sr-RS': 'Српски' },
    { 'mk-MK': 'Македонски' },
    { 'mn-MN': 'монгол' },
    { 'ru-RU': 'Русский' },
    { 'uk-UA': 'Українська' },
    { 'ja-JP': '日本語' },
    { 'ko-KR': '한국어' },
    { 'th-TH': 'ไทย' },
    { 'km-KH': 'ភាសាខ្មែរ' },
    { 'lo-LA': 'ພາສາລາວ' },
    { 'ar-SA': 'العربية' },
    { 'ms-MY': 'بهاس ملايو' },
    { 'ps-AF': 'پښتو' },
    { 'am-ET': 'አማርኛ' },
    { 'bn-IN': 'বাংলা' },
    { 'he-IL': 'עברית' },
    { 'hy-AM': 'Հայերեն' },
    { 'ka-GE': 'ქართული ენა' },
    { 'my-MM': 'ဗမာစကား' },
    { 'si-LK': 'සිංහල' },
    { 'gu-IN': 'ગુજરાતી' },
    { 'hi-IN': 'हिन्दी' },
    { 'kn-IN': 'ಕನ್ನಡ' },
    { 'ml-IN': 'മലയാളം' },
    { 'mr-IN': 'मराठी' },
    { 'or-IN': 'ଓଡିଆ' },
    { 'pa-IN': 'ਪੰਜਾਬੀ' },
    { 'ta-IN': 'தமிழ்' },
    { 'te-IN': 'తెలుగు' },
    { 'ur-IN': 'اردو' },
    { 'ne-NP': 'नेपाली' },
    { 'zh-CN': '中文' },
    { 'zh-HK': '中文 (香港)' },
    { 'zh-TW': '繁體中文' },
];

function ChatTrix({input, setInput, voiceChat, upLoad, handleSendMessage, voiceStatus = null, startVoice = null, stopVoice = null, lang = null, changeLang = null, typeEditor = 'frame'}) {

    const editorRef = useRef(null);
    const handleSendMessageRef = useRef(handleSendMessage);

    useEffect(() => {
      handleSendMessageRef.current = handleSendMessage;
    }, [handleSendMessage]);

    useEffect(() => {
      const editorElement = editorRef.current;
      if (editorElement && voiceChat !== '') {
        editorElement.editor.loadHTML(voiceChat);
      }
    }, [voiceChat]);

    useEffect(() => {
      const editorElement = editorRef.current;
      if (editorElement && input === '') {
        editorElement.editor.loadHTML(input);
      }
    }, [input]);

    useEffect(() => {
      const editorElement = editorRef.current;
      const inputElement = document.querySelector('#trix-input');

      if (editorElement && inputElement) {
        inputElement.value = input;
        editorElement.editor.loadHTML(input);
      }

      const handleChange = (event) => {
          setInput(event.target.innerHTML);
      };

      const handleGetFile = async (event) => {
        const attachment = event.attachment;
        if (!attachment.file) return;
        await upLoad(attachment.file);
        event.target.value = '';
      };

      const handleKeyDown = (e) => {
        if (e.key === 'Enter') {
          if (e.shiftKey) {
            return;
          } else {
            e.preventDefault();
            handleSendMessageRef.current();
          }
        }
      };

      editorElement.addEventListener('keydown', handleKeyDown);
      editorElement.addEventListener('trix-change', handleChange);
      document.addEventListener('trix-attachment-add', handleGetFile);

      return () => {
        editorElement.removeEventListener('keydown', handleKeyDown);
        editorElement.removeEventListener('trix-change', handleChange);
        document.removeEventListener('trix-attachment-add', handleGetFile);
      };
    }, []);

    return (
      <div className='overflow-hidden border rounded-3 flex-grow-1'>
        <trix-toolbar id='custom-toolbar' class={`border-bottom ${typeEditor === 'frame' ? 'd-flex' : 'd-none'}`}>
          {typeEditor === 'frame' &&
            <div className='trix-button-row p-1'>
              <span className='trix-button-group trix-button-group--text-tools mb-0 border-0'>
                <ChatFile upLoad={upLoad} />
                <ChatVoice voiceStatus={voiceStatus} startVoice={startVoice} stopVoice={stopVoice} />
                <Form.Select className='ms-2' value={lang} title={Drupal.t('Change language')} onChange={(e) => {changeLang(e.target.value)}}>
                  <option hidden>{Drupal.t('Select languages')}</option>
                  {languages.map((item) => {
                    const [code, label] = Object.entries(item)[0];
                    return (<option key={code} value={code}>{label}</option>);
                  })}
                </Form.Select>
              </span>
            </div>
          }
        </trix-toolbar>
        <trix-editor ref={editorRef} class='trix-editor border-0' input='editor' toolbar='custom-toolbar'></trix-editor>
        <input id='trix-input' type='hidden' name='content'/>
      </div>
    );
}

export default memo(ChatTrix);
