<?php

namespace Drupal\ai_auto_embedding\Plugin\QueueWorker;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Queue\QueueWorkerBase;
use Drupal\Core\Render\Renderer;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\deepseek\EmbeddingHandlerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Queue embedding entity.
 *
 * @QueueWorker(
 *   id = "queue_embedding_entity",
 *   title = @Translation("Queue embedding entity"),
 *   cron = {"time" = 360}
 * )
 */
class QueueEmbeddingEntity extends QueueWorkerBase implements ContainerFactoryPluginInterface {
  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public function __construct(
    array $configuration,
    $plugin_id,
    $plugin_definition,
    protected EntityTypeManagerInterface $entityTypeManager,
    protected Renderer $renderer,
    protected EmbeddingHandlerInterface $embeddingHandler,
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('entity_type.manager'),
      $container->get('renderer'),
      $container->get('deepseek.embedding'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function processItem($data) {
    $storageManage = $this->entityTypeManager->getStorage($data['entity_type']);
    $entity = $storageManage->load($data['id']);
    $view_builder = $this->entityTypeManager->getViewBuilder($data['entity_type']);
    $render_array = $view_builder->view($entity, $data['view_mode']);
    $content = html_entity_decode($this->renderer->renderRoot($render_array));
    $this->embeddingHandler->saveEmbedding($data['entity_type'], $entity->id(), trim($content));
  }

}
